<?php 

/**
 *  API Endpoints
 *  
 *  Taxonomies
 *  http://qmlifestyle.git/wp-json/wp/v2/partnerscat?per_page=50
 *  http://qmlifestyle.git/wp-json/wp/v2/partnerscat/15
 * 	
 * 	Custom Post Types
 *  http://qmlifestyle.git/wp-json/wp/v2/slide?per_page=20
 *  http://qmlifestyle.git/wp-json/wp/v2/resort?per_page=20
 *  
 *  http://qmlifestyle.git/wp-json/wp/v2/partner?per_page=20
 *  http://qmlifestyle.git/wp-json/wp/v2/partner?partnerscat=15 (filter by partnerscat)
 *  http://qmlifestyle.git/wp-json/wp/v2/partner?filter[partnerscat]=15 (filter by partnerscat)
 */

/**
 * Debug
 */
if (!function_exists('pr')) {
	function pr($v){
		echo sprintf('<pre class="dump">%s</pre>', print_r($v, true));
	}
}

add_theme_support( 'post-thumbnails' );

// Trim categories description
add_action( 'admin_head-edit-tags.php', 'admin_edit_tags' );
function admin_edit_tags() {
    add_filter( 'get_terms', 'admin_trim_category_description', 10, 2 );
}
function admin_trim_category_description( $terms, $taxonomies ) {
    if( 'category' != $taxonomies[0] )
        return $terms;
    foreach( $terms as $key=>$term )
        $terms[$key]->description = substr( $term->description, 0, 150 );
    return $terms;
}


/**
 * Order Slides by Menu Order
 */
function change_rest_query( $args, $request ){
	$args['orderby'] = 'menu_order';
	return $args;
}

add_filter( 'rest_slide_query', 'change_rest_query', 10, 2 );

/**
 * Partners Category
 * 
 * Apoio Jurídico
 * Arquitetos
 * Aquitetos Paisagistas
 * Arquitetos Decoradores
 * Babysiters
 * Canalização / Desentupimentos
 * Carros Topo de Gama
 * Carros Clássicos
 * Escolas
 * Escolas de Equitação
 * Entregas e Mudanças
 * Eventos Exclusivos
 * Fotógrafos
 * Hair & Beauty Treatments
 * Instituições Públicas
 * Jardinagem
 * Lavandarias
 * Limpezas Gerais
 * Limpeza De Piscinas
 * Luxury Goods
 * Obras Gerais
 * Pet Care
 * Restaurantes
 * Segurança 
 * Vinhos e Champagne
 */
function partners_category_taxonomy() {

	$labels = array(
		'name'                       => _x( 'Partners Categories', 'Taxonomy General Name', 'qm' ),
		'singular_name'              => _x( 'Partners Category', 'Taxonomy Singular Name', 'qm' ),
		'menu_name'                  => __( 'Partners Category', 'qm' ),
		'all_items'                  => __( 'All Items', 'qm' ),
		'parent_item'                => __( 'Parent Item', 'qm' ),
		'parent_item_colon'          => __( 'Parent Item:', 'qm' ),
		'new_item_name'              => __( 'New Item Name', 'qm' ),
		'add_new_item'               => __( 'Add New Item', 'qm' ),
		'edit_item'                  => __( 'Edit Item', 'qm' ),
		'update_item'                => __( 'Update Item', 'qm' ),
		'view_item'                  => __( 'View Item', 'qm' ),
		'separate_items_with_commas' => __( 'Separate items with commas', 'qm' ),
		'add_or_remove_items'        => __( 'Add or remove items', 'qm' ),
		'choose_from_most_used'      => __( 'Choose from the most used', 'qm' ),
		'popular_items'              => __( 'Popular Items', 'qm' ),
		'search_items'               => __( 'Search Items', 'qm' ),
		'not_found'                  => __( 'Not Found', 'qm' ),
		'no_terms'                   => __( 'No items', 'qm' ),
		'items_list'                 => __( 'Items list', 'qm' ),
		'items_list_navigation'      => __( 'Items list navigation', 'qm' ),
	);
	$args = array(
		'labels'                     => $labels,
		'hierarchical'               => true,
		'public'                     => true,
		'show_ui'                    => true,
		'show_admin_column'          => true,
		'show_in_nav_menus'          => true,
		'show_tagcloud'              => true,
		'show_in_rest'               => true,
	);
	register_taxonomy( 'partnerscat', array( 'partner' ), $args );

}
add_action( 'init', 'partners_category_taxonomy', 0 );

// Register Custom Post Type
function slides_post_type() {

	$labels = array(
		'name'                  => _x( 'Slides', 'Post Type General Name', 'qm' ),
		'singular_name'         => _x( 'Slide', 'Post Type Singular Name', 'qm' ),
		'menu_name'             => __( 'Slides', 'qm' ),
		'name_admin_bar'        => __( 'Slide', 'qm' ),
		'archives'              => __( 'Item Archives', 'qm' ),
		'attributes'            => __( 'Item Attributes', 'qm' ),
		'parent_item_colon'     => __( 'Parent Item:', 'qm' ),
		'all_items'             => __( 'All Items', 'qm' ),
		'add_new_item'          => __( 'Add New Item', 'qm' ),
		'add_new'               => __( 'Add New', 'qm' ),
		'new_item'              => __( 'New Item', 'qm' ),
		'edit_item'             => __( 'Edit Item', 'qm' ),
		'update_item'           => __( 'Update Item', 'qm' ),
		'view_item'             => __( 'View Item', 'qm' ),
		'view_items'            => __( 'View Items', 'qm' ),
		'search_items'          => __( 'Search Item', 'qm' ),
		'not_found'             => __( 'Not found', 'qm' ),
		'not_found_in_trash'    => __( 'Not found in Trash', 'qm' ),
		'featured_image'        => __( 'Featured Image', 'qm' ),
		'set_featured_image'    => __( 'Set featured image', 'qm' ),
		'remove_featured_image' => __( 'Remove featured image', 'qm' ),
		'use_featured_image'    => __( 'Use as featured image', 'qm' ),
		'insert_into_item'      => __( 'Insert into item', 'qm' ),
		'uploaded_to_this_item' => __( 'Uploaded to this item', 'qm' ),
		'items_list'            => __( 'Items list', 'qm' ),
		'items_list_navigation' => __( 'Items list navigation', 'qm' ),
		'filter_items_list'     => __( 'Filter items list', 'qm' ),
	);
	$args = array(
		'label'                 => __( 'Slide', 'qm' ),
		'description'           => __( 'Slides', 'qm' ),
		'labels'                => $labels,
		'supports'              => array( 'title', 'editor', 'thumbnail' ),
		'taxonomies'            => array( 'category', 'post_tag' ),
		'hierarchical'          => false,
		'public'                => true,
		'show_ui'               => true,
		'show_in_rest'          => true,
		'show_in_menu'          => true,
		'menu_position'         => 5,
		'show_in_admin_bar'     => true,
		'show_in_nav_menus'     => true,
		'can_export'            => true,
		'has_archive'           => true,
		'exclude_from_search'   => false,
		'publicly_queryable'    => true,
		'capability_type'       => 'page',
	);
	register_post_type( 'slide', $args );

}
add_action( 'init', 'slides_post_type', 0 );

// Register Custom Post Type
function partners_post_type() {

	$labels = array(
		'name'                  => _x( 'Partners', 'Post Type General Name', 'qm' ),
		'singular_name'         => _x( 'Partner', 'Post Type Singular Name', 'qm' ),
		'menu_name'             => __( 'Partners', 'qm' ),
		'name_admin_bar'        => __( 'Partner', 'qm' ),
		'archives'              => __( 'Item Archives', 'qm' ),
		'attributes'            => __( 'Item Attributes', 'qm' ),
		'parent_item_colon'     => __( 'Parent Item:', 'qm' ),
		'all_items'             => __( 'All Items', 'qm' ),
		'add_new_item'          => __( 'Add New Item', 'qm' ),
		'add_new'               => __( 'Add New', 'qm' ),
		'new_item'              => __( 'New Item', 'qm' ),
		'edit_item'             => __( 'Edit Item', 'qm' ),
		'update_item'           => __( 'Update Item', 'qm' ),
		'view_item'             => __( 'View Item', 'qm' ),
		'view_items'            => __( 'View Items', 'qm' ),
		'search_items'          => __( 'Search Item', 'qm' ),
		'not_found'             => __( 'Not found', 'qm' ),
		'not_found_in_trash'    => __( 'Not found in Trash', 'qm' ),
		'featured_image'        => __( 'Featured Image', 'qm' ),
		'set_featured_image'    => __( 'Set featured image', 'qm' ),
		'remove_featured_image' => __( 'Remove featured image', 'qm' ),
		'use_featured_image'    => __( 'Use as featured image', 'qm' ),
		'insert_into_item'      => __( 'Insert into item', 'qm' ),
		'uploaded_to_this_item' => __( 'Uploaded to this item', 'qm' ),
		'items_list'            => __( 'Items list', 'qm' ),
		'items_list_navigation' => __( 'Items list navigation', 'qm' ),
		'filter_items_list'     => __( 'Filter items list', 'qm' ),
	);
	$args = array(
		'label'                 => __( 'partner', 'qm' ),
		'description'           => __( 'partners', 'qm' ),
		'labels'                => $labels,
		'supports'              => array( 'title', 'editor', 'thumbnail' ),
		'taxonomies'            => array( 'partnerscat'),
		'hierarchical'          => false,
		'public'                => true,
		'show_ui'               => true,
		'show_in_rest'          => true,
		'show_in_menu'          => true,
		'menu_position'         => 5,
		'show_in_admin_bar'     => true,
		'show_in_nav_menus'     => true,
		'can_export'            => true,
		'has_archive'           => true,
		'exclude_from_search'   => false,
		'publicly_queryable'    => true,
		'capability_type'       => 'page',
	);
	register_post_type( 'partner', $args );

}
add_action( 'init', 'partners_post_type', 0 );


/**
 * Resorts Custom Post Type
 * 
 * Aldeamento Marinha Freixos
 * Martinhal Cascais Family Hotel & Resort
 * Marinha Sul Residences
 * Onyria Quinta da Marinha Hotel Resort
 * Sheraton Cascais Resort
 * Marinha Prime
 * Bloom Marinha
 * Quinta da Marinha Original
 * The Oitavos
 * Condominio Marinha Golf
 * Village Du Golf
 * Condominio Quinta da Marinha Aldeamento C
 */
function resorts_post_type() {

	$labels = array(
		'name'                  => _x( 'Resorts', 'Post Type General Name', 'qm' ),
		'singular_name'         => _x( 'Resort', 'Post Type Singular Name', 'qm' ),
		'menu_name'             => __( 'Resorts', 'qm' ),
		'name_admin_bar'        => __( 'Resort', 'qm' ),
		'archives'              => __( 'Item Archives', 'qm' ),
		'attributes'            => __( 'Item Attributes', 'qm' ),
		'parent_item_colon'     => __( 'Parent Item:', 'qm' ),
		'all_items'             => __( 'All Items', 'qm' ),
		'add_new_item'          => __( 'Add New Item', 'qm' ),
		'add_new'               => __( 'Add New', 'qm' ),
		'new_item'              => __( 'New Item', 'qm' ),
		'edit_item'             => __( 'Edit Item', 'qm' ),
		'update_item'           => __( 'Update Item', 'qm' ),
		'view_item'             => __( 'View Item', 'qm' ),
		'view_items'            => __( 'View Items', 'qm' ),
		'search_items'          => __( 'Search Item', 'qm' ),
		'not_found'             => __( 'Not found', 'qm' ),
		'not_found_in_trash'    => __( 'Not found in Trash', 'qm' ),
		'featured_image'        => __( 'Featured Image', 'qm' ),
		'set_featured_image'    => __( 'Set featured image', 'qm' ),
		'remove_featured_image' => __( 'Remove featured image', 'qm' ),
		'use_featured_image'    => __( 'Use as featured image', 'qm' ),
		'insert_into_item'      => __( 'Insert into item', 'qm' ),
		'uploaded_to_this_item' => __( 'Uploaded to this item', 'qm' ),
		'items_list'            => __( 'Items list', 'qm' ),
		'items_list_navigation' => __( 'Items list navigation', 'qm' ),
		'filter_items_list'     => __( 'Filter items list', 'qm' ),
	);
	$args = array(
		'label'                 => __( 'resort', 'qm' ),
		'description'           => __( 'resorts', 'qm' ),
		'labels'                => $labels,
		'supports'              => array( 'title', 'editor', 'thumbnail' ),
		'taxonomies'            => array(),
		'hierarchical'          => false,
		'public'                => true,
		'show_ui'               => true,
		'show_in_rest'          => true,
		'show_in_menu'          => true,
		'menu_position'         => 5,
		'show_in_admin_bar'     => true,
		'show_in_nav_menus'     => true,
		'can_export'            => true,
		'has_archive'           => true,
		'exclude_from_search'   => false,
		'publicly_queryable'    => true,
		'capability_type'       => 'page',
	);
	register_post_type( 'resort', $args );

}
add_action( 'init', 'resorts_post_type', 0 );


/*
function post_featured_image_json( $data, $post, $context ) {
	$featured_image_id = $data->data['featured_media']; // get featured image id
	$featured_image_url = wp_get_attachment_image_src( $featured_image_id, 'original' ); // get url of the original size
  
	if( $featured_image_url ) {
	  $data->data['featured_image_url'] = $featured_image_url[0];
	}
  
	return $data;
  }
  add_filter( 'rest_prepare_post', 'post_featured_image_json', 10, 3 );
  */


  function post_fetured_image_json( $data, $post, $context ) {

	$featured_image_id = $data->data['featured_media']; // get featured image id
	$featured_image_url = wp_get_attachment_image_src( $featured_image_id, 'original' ); // get url of the original size
	
	if( $featured_image_url ) {
		$data->data['featured_image_url'] = $featured_image_url[0];
	}

	$data->remove_link( 'collection' );
    $data->remove_link( 'self' );
    $data->remove_link( 'about' );
    $data->remove_link( 'author' );
    $data->remove_link( 'replies' );
    $data->remove_link( 'version-history' );
    $data->remove_link( 'https://api.w.org/featuredmedia' );
    $data->remove_link( 'https://api.w.org/attachment' );
    $data->remove_link( 'https://api.w.org/term' );
	$data->remove_link( 'curies' );

	foreach(['date_gmt', 'modified', 'modified_gmt', 'guid', 'template', 'categories', 'tags'] as $key){
		if(isset($data->data[$key])){
			unset($data->data[$key]);
		}
	}

	return $data;
}
add_filter( 'rest_prepare_slide', 'post_fetured_image_json', 10, 3 );
add_filter( 'rest_prepare_resort', 'post_fetured_image_json', 10, 3 );
add_filter( 'rest_prepare_partner', 'post_fetured_image_json', 10, 3 );

function taxonomy_acf( $data, $post, $context ) {

	//$term = get_queried_object();

	//pr($term);

	$data->remove_link( 'collection' );
    $data->remove_link( 'self' );
    $data->remove_link( 'about' );
    $data->remove_link( 'author' );
    $data->remove_link( 'replies' );
    $data->remove_link( 'version-history' );
    $data->remove_link( 'https://api.w.org/featuredmedia' );
    $data->remove_link( 'https://api.w.org/attachment' );
    $data->remove_link( 'https://api.w.org/term' );
	$data->remove_link( 'curies' );

	$term = sprintf('%s_%s', $post->taxonomy, $post->term_taxonomy_id);
	
	$data->data['color'] = get_field('color', $term);
	
	$data->data['icon'] = get_field('icon', $term);
	$data->data['icon'] = preg_replace('@fa. fa-@', '', $data->data['icon']);
	
	$data->data['route'] = 'Place';

	$data->data['thumb'] = get_field('featured_image', $term);

	foreach(['_links'] as $key){
		if(isset($data->data[$key])){
			unset($data->data[$key]);
		}
	}

	return $data;
}

add_filter( 'rest_prepare_partnerscat', 'taxonomy_acf', 10, 3 );


  // Clear the WP-JSON index
  //add_filter('rest_index', 'nstrm_hide_wp_json_index');
  function nstrm_hide_wp_json_index( $response ){
	  return array();
  }


?>